# QSARModelingPy Core

[![PyPI](https://img.shields.io/pypi/v/qsarmodelingpy)](https://pypi.org/project/qsarmodelingpy/)
![PyPI - Format](https://img.shields.io/pypi/format/qsarmodelingpy)

**QSARModeling** é uma ferramenta gratuita e open-source para a construção e validação de modelos QSAR e QSPR. [Originalmente desenvolvido](https://doi.org/10.1590/S0100-40422013000400013) em Java, esta biblioteca em Python permite ao usuário a aplicação programática, personalizável e escalável dos recursos do software.

Alguns recursos podem ser destacados, como:

-   Redução de dimensionalidade baseada em variância, correlação e autocorrelação;
-   Seleção de variáveis: Ordered Predictors Selection (OPS) ou Algoritmo Genético (GA)
-   Validação cruzada: y-randomization e leave-N-out
-   Validação externa

## Uso

> Esta versão do QSARModelingPy Core é uma biblioteca para a linguagem de programação Python, com foco em programadores que desejam implementar sua própria versão do QSAR Modeling, expandi-lo ou utilizá-lo programaticamente. Se deseja uma versão funcional desenvolvida para o usuário final, veja [QSARModelingPy](https://github.com/hellmrf/QSARModelingPy).

Para utilizar, instale a biblioteca em seu ambiente.

```sh
$ pip install qsarmodelingpy
```
